// *******************************************************************
//
// Demonstration of how to use TimedMT4Ticks.dll to ensure that
// an MT4 chart window gets its start() function called at least
// every n seconds 
//
// *******************************************************************


// Import of DLL function. The DLL file must be present in
// experts\libraries or on the system path. The "Allow DLL imports"
// setting must be turned on
#import "TimedMT4Ticks.dll"
   int SetupTickTimer(int ChartWindowHandle, int PeriodInSeconds);
   int RemoveTickTimer(int TimerHandle);
#import


// Global variable which holds the handle allocated to this chart's timer,
// and which needs to be passed to RemoveTickTimer() during the EA's deinit()
int glbTickTimerHandle = 0;


// Initialisation. Set up timed ticks
int init()
{
   // Set up a tick timer by passing the chart's window handle, and the 
   // frequency of the timer in seconds. This passes back a handle
   // which needs to be stored for use in deinit()
   glbTickTimerHandle = SetupTickTimer(WindowHandle(Symbol(), Period()), 2);
   
   Print("Timer handle: " + glbTickTimerHandle);
   return (0);
}


// Termination. Remove the timer 
int deinit()
{
   // Remove the timer
   int res = RemoveTickTimer(glbTickTimerHandle);
   
   Print("Timer removal result: " + res);
   return (0);
}


// EA start function which should get called at least every n seconds,
// regardless of whether there are any market ticks. N.B. This means
// that the start() function will potentially continue to run over
// weekends while the market is closed 
int start()
{
   Comment("Most recent tick: " + TimeToStr(TimeLocal(), TIME_DATE | TIME_SECONDS));
   return (0);
}

